package com.ruoyi.web.controller.aliexpress;

import com.global.iop.api.IopClient;
import com.global.iop.api.IopClientImpl;
import com.global.iop.api.IopRequest;
import com.global.iop.api.IopResponse;
import com.global.iop.domain.Protocol;
import com.global.iop.util.ApiException;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.controller.aliexpress.dto.freight.FreightCalculateFreightDTO;
import com.ruoyi.web.controller.aliexpress.dto.freight.FreightGetFreightSettingByTemplateQueryDTO;
import com.ruoyi.web.controller.aliexpress.dto.freight.FreightListFreightTemplateDTO;
import com.ruoyi.web.core.config.AliexpressAuthClientConfig;
import com.ruoyi.web.enumerate.AliexpressFreightEnu;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * @author ldj
 * @date 2024/2/28 14:34
 * @Description: ...
 * @Version 1.0
 */
@RestController
@Api("对接速卖通 类目")
@RequestMapping("/aliexpress/freight")
public class AliexpressFreightController {

    @Resource
    private AliexpressAuthClientConfig AliexpressAuthClientConfig;

    //用户运费模板列表信息
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("aliexpress.freight.redefining.listfreighttemplate");
IopResponse response = client.execute(request, accessToken, Protocol.TOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 用户运费模板列表信息
     */
    @Log(title = "用户运费模板列表信息", businessType = BusinessType.SELECT)
    @ApiOperation("用户运费模板列表信息")
    @PostMapping("/listFreightTemplate")
    public String listFreightTemplate(@RequestBody FreightListFreightTemplateDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressFreightEnu.LIST_FREIGHT_TEMPLATE.getApiName());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }

    //运费计算
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("aliexpress.freight.redefining.calculatefreight");
request.addApiParameter("height", "1");
request.addApiParameter("weight", "1");
request.addApiParameter("pack_add_weight", "1");
request.addApiParameter("count", "1");
request.addApiParameter("freight_template_id", "1000");
request.addApiParameter("pack_add_unit", "1");
request.addApiParameter("is_custom_pack_weight", "false");
request.addApiParameter("width", "1");
request.addApiParameter("length", "1");
request.addApiParameter("product_price", "{\"amount\":\"100.01\",\"cent\":\"10000\",\"currency_code\":\"USD\"}");
request.addApiParameter("pack_base_unit", "1");
request.addApiParameter("country", "RU");
IopResponse response = client.execute(request, accessToken, Protocol.TOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 运费计算
     */
    @Log(title = "运费计算", businessType = BusinessType.SELECT)
    @ApiOperation("运费计算")
    @PostMapping("/calculateFreight")
    public String calculateFreight(@RequestBody FreightCalculateFreightDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressFreightEnu.CALCULATE_FREIGHT.getApiName());
        request.addApiParameter("height", reqDto.getHeight());
        request.addApiParameter("weight", reqDto.getWeight());
        request.addApiParameter("pack_add_weight", reqDto.getPack_add_weight());
        request.addApiParameter("count", reqDto.getCount());
        request.addApiParameter("freight_template_id", reqDto.getFreight_template_id());
        request.addApiParameter("pack_add_unit", reqDto.getPack_add_unit());
        request.addApiParameter("is_custom_pack_weight", reqDto.getIs_custom_pack_weight());
        request.addApiParameter("width", reqDto.getWidth());
        request.addApiParameter("length", reqDto.getLength());
        request.addApiParameter("product_price", reqDto.getProduct_price());
        request.addApiParameter("pack_base_unit", reqDto.getPack_base_unit());
        request.addApiParameter("country", reqDto.getCountry());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }

    //通过模板ID获取单个运费模板内容
    /*
IopClient client = new IopClient(url, appkey, appSecret);
IopRequest request = new IopRequest();
request.setApiName("aliexpress.freight.redefining.getfreightsettingbytemplatequery");
request.addApiParameter("template_id", "1000");
IopResponse response = client.execute(request, accessToken, Protocol.TOP);
System.out.println(response.getBody());
Thread.sleep(10);
     */

    /**
     * 通过模板ID获取单个运费模板内容
     */
    @Log(title = "通过模板ID获取单个运费模板内容", businessType = BusinessType.SELECT)
    @ApiOperation("通过模板ID获取单个运费模板内容")
    @PostMapping("/getFreightSettingByTemplateQuery")
    public String getFreightSettingByTemplateQuery(@RequestBody FreightGetFreightSettingByTemplateQueryDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressFreightEnu.GET_FREIGHT_SETTING_BY_TEMPLATE_QUERY.getApiName());
        request.addApiParameter("template_id", reqDto.getTemplate_id());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }


}
