package com.ruoyi.web.controller.aliexpress;

import com.global.iop.api.IopClient;
import com.global.iop.api.IopClientImpl;
import com.global.iop.api.IopRequest;
import com.global.iop.api.IopResponse;
import com.global.iop.domain.Protocol;
import com.global.iop.util.ApiException;
import com.global.iop.util.FileItem;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.controller.aliexpress.dto.photobank.*;
import com.ruoyi.web.core.config.AliexpressAuthClientConfig;
import com.ruoyi.web.enumerate.AliexpressImageEnu;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;

/**
 * @author ldj
 * @date 2024/2/27 18:18
 * @Description: ...
 * @Version 1.0
 */
@RestController
@Api("对接速卖通 图片")
@RequestMapping("/aliexpress/image")
public class AliexpressImageController {

    @Resource
    private AliexpressAuthClientConfig AliexpressAuthClientConfig;

    //上传图片到临时目录
    /**    {
     IopClient client = new IopClient(url, appkey, appSecret);
     IopRequest request = new IopRequest();
     request.setApiName("aliexpress.image.redefining.uploadtempimage");
     request.addFileParameter("file_data",new FileItem("/Users/D ocuments/book.jpg"));
     request.addApiParameter("src_file_name", "1.jpg");
     IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     System.out.println(response.getBody());
     Thread.sleep(10);
     }
     **/
    /**
     * 上传图片到临时目录
     */
    @Log(title = "上传图片到临时目录", businessType = BusinessType.SELECT)
    @ApiOperation("上传图片到临时目录")
    @PostMapping("/uploadTempImage")
    public String uploadTempImage(@RequestParam("file") MultipartFile file, @RequestBody PhotoBankUploadTempImageDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.UPLOAD_TEMP_IMAGE.getApiName());
        try {
            request.addFileParameter("file_data", new FileItem(file.getOriginalFilename(), file.getInputStream(), file.getContentType()));
        } catch (IOException e) {
            return "文件上传失败,IO异常!";
        }
        request.addApiParameter("src_file_name", file.getOriginalFilename());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //上传图片到临时目录(推荐使用)

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.image.redefining.uploadtempimageforsdk");
     * request.addFileParameter("file_data",new FileItem("/Users/D ocuments/book.jpg"));
     * request.addApiParameter("src_file_name", "1.jpg");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "上传图片到临时目录(推荐使用)", businessType = BusinessType.SELECT)
    @ApiOperation("上传图片到临时目录(推荐使用)")
    @PostMapping("/uploadTempImageForSdk")
    public String uploadTempImageForSdk(@RequestParam("file") MultipartFile file, @RequestBody PhotoBankUploadTempImageDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.UPLOAD_TEMP_IMAGE_FOR_SDK.getApiName());
        try {
            request.addFileParameter("file_data", new FileItem(file.getOriginalFilename(), file.getInputStream(), file.getContentType()));
        } catch (IOException e) {
            return "文件上传失败,IO异常!";
        }
        request.addApiParameter("src_file_name", file.getOriginalFilename());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //上传图片到图片银行

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.uploadimage");
     * request.addApiParameter("file_name", "0");
     * request.addApiParameter("group_id", "0");
     * request.addFileParameter("image_bytes",new FileItem("/Users/D ocuments/book.jpg"));
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "上传图片到图片银行", businessType = BusinessType.SELECT)
    @ApiOperation("上传图片到图片银行")
    @PostMapping("/uploadImage")
    public String uploadImage(@RequestParam("file") MultipartFile file, @RequestBody PhotoBankUploadImageDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.UPLOAD_IMAGE.getApiName());
        request.addApiParameter("file_name", reqDto.getFile_name());
        request.addApiParameter("group_id", reqDto.getGroup_id());
        try {
            request.addFileParameter("image_bytes", new FileItem(file.getOriginalFilename(), file.getInputStream(), file.getContentType()));
        } catch (IOException e) {
            return "文件上传失败,IO异常!";
        }
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //上传图片到图片银行(推荐使用)

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.uploadimageforsdk");
     * request.addApiParameter("group_id", "0");
     * request.addFileParameter("image_bytes",new FileItem("/Users/D ocuments/book.jpg"));
     * request.addApiParameter("file_name", "0");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "上传图片到图片银行(推荐使用)", businessType = BusinessType.SELECT)
    @ApiOperation("上传图片到图片银行(推荐使用)")
    @PostMapping("/uploadImageForSdk")
    public String uploadImageForSdk(@RequestParam("file") MultipartFile file, @RequestBody PhotoBankUploadImageDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.UPLOAD_IMAGE_FOR_SDK.getApiName());
        request.addApiParameter("file_name", reqDto.getFile_name());
        request.addApiParameter("group_id", reqDto.getGroup_id());
        try {
            request.addFileParameter("image_bytes", new FileItem(file.getOriginalFilename(), file.getInputStream(), file.getContentType()));
        } catch (IOException e) {
            return "文件上传失败,IO异常!";
        }
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //删除未被引用图片

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.delunusephoto");
     * request.addApiParameter("aeop_delete_image_request", "{\"image_repository_id\":\"100403959\"}");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "删除未被引用图片", businessType = BusinessType.SELECT)
    @ApiOperation("删除未被引用图片")
    @PostMapping("/deleteUnUsePhoto")
    public String deleteUnUsePhoto(@RequestBody PhotoBankDeleteUnUsePhotoDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.DELETE_UNUSE_PHOTO.getApiName());
        request.addApiParameter("aeop_delete_image_request", reqDto.getAeop_delete_image_request());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //图片银行列表分页查询

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.listimagepagination");
     * request.addApiParameter("aeop_image_pagination_request", "{\"group_id\":\"0\",\"current_page\":\"0\",\"location_type\":\"0\",\"page_size\":\"0\"}");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "图片银行列表分页查询", businessType = BusinessType.SELECT)
    @ApiOperation("图片银行列表分页查询")
    @PostMapping("/listImagePagination")
    public String listImagePagination(@RequestBody PhotoBankListImagePaginationDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.LIST_IMAGE_PAGINATION.getApiName());
        request.addApiParameter("aeop_image_pagination_request", reqDto.getAeop_image_pagination_request());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //查询图片银行分组信息

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.listgroup");
     * request.addApiParameter("group_id", "8401");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "查询图片银行分组信息", businessType = BusinessType.SELECT)
    @ApiOperation("查询图片银行分组信息")
    @PostMapping("/listGroup")
    public String listGroup(@RequestBody PhotoBankListGroupDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.LIST_GROUP.getApiName());
        request.addApiParameter("group_id", reqDto.getGroup_id());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //根据path查询图片信息

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.queryphotobankimagebypaths");
     * request.addApiParameter("paths", "HTB1rxqmHpXXXXXBXFXXq6xXFXXXm.jpg,HBA1rxqmHpXXXXXBXFXXq6xXFXXXm.jpg");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "根据path查询图片信息", businessType = BusinessType.SELECT)
    @ApiOperation("根据path查询图片信息")
    @PostMapping("/queryPhotoBankImageByPaths")
    public String queryPhotoBankImageByPaths(@RequestBody PhotoBankQueryPhotoBankImageByPathsDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.QUERY_PHOTO_BANK_IMAGE_BY_PATHS.getApiName());
        request.addApiParameter("paths", reqDto.getPaths());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
    //获取图片银行信息

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.getphotobankinfo");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "获取图片银行信息", businessType = BusinessType.SELECT)
    @ApiOperation("获取图片银行信息")
    @PostMapping("/getPhotoBankInfo")
    public String getPhotoBankInfo(@RequestBody PhotoBankGetPhotoBankInfoDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.GET_PHOTO_BANK_INFO.getApiName());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }

    //获取白底图

    /**
     * {
     * IopClient client = new IopClient(url, appkey, appSecret);
     * IopRequest request = new IopRequest();
     * request.setApiName("aliexpress.photobank.redefining.wbimage.get");
     * request.addApiParameter("get_wb_image_request", "{\"original_image_url\":\"https://ae01.alicdn.com/kf/H401119d45e2e4e0ab21a28e3e304b65dT.png\"}");
     * IopResponse response = client.execute(request, accessToken, Protocol.TOP);
     * System.out.println(response.getBody());
     * Thread.sleep(10);
     * }
     **/
    @Log(title = "获取白底图", businessType = BusinessType.SELECT)
    @ApiOperation("获取白底图")
    @PostMapping("/getWbImage")
    public String getWbImage(@RequestBody PhotoBankGetWbImageDTO reqDto) throws ApiException {
        IopClient client = new IopClientImpl(AliexpressAuthClientConfig.getUrl(), AliexpressAuthClientConfig.getAppKey(), AliexpressAuthClientConfig.getAppSecret());
        IopRequest request = new IopRequest();
        request.setApiName(AliexpressImageEnu.GET_WB_IMAGE.getApiName());
        request.addApiParameter("get_wb_image_request", reqDto.getGet_wb_image_request());
        IopResponse response = client.execute(request, reqDto.getAccessToken(), Protocol.TOP);
        return response.getGopResponseBody();
    }
}
