package com.ruoyi.ap;

import java.util.concurrent.atomic.AtomicStampedReference;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

public class ABADemo {
    static AtomicStampedReference<Integer> atomicStampedRef =
            new AtomicStampedReference<Integer>(100, 0);

    private static final Lock lock = new ReentrantLock();

    public static void main(String[] args) {

        Thread refT1 = new Thread(() -> {
            try {
                // 获取当前的引用和时间戳
                int stamp = atomicStampedRef.getStamp();
                Integer refValue = atomicStampedRef.getReference();

                // 尝试修改引用和时间戳
                boolean success = atomicStampedRef.compareAndSet(refValue, refValue + 100, stamp, stamp + 1);
                System.out.println("refT1 Success:" + success);
                // 模拟其他操作，使线程T1暂停
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }

                // 尝试将值改回原值，此时时间戳已经改变
                stamp = atomicStampedRef.getStamp();
                success = atomicStampedRef.compareAndSet(refValue + 100, refValue, stamp, stamp + 1);
                System.out.println("refT1 Success:" + success);

            } catch (Exception e) {
                e.printStackTrace();
            }
        });

        Thread refT2 = new Thread(() -> {
            try {
                int stamp = atomicStampedRef.getStamp();
                Integer refValue = atomicStampedRef.getReference();

                // 等待线程T1完成第一次修改
                Thread.sleep(500);

                // 尝试修改引用和时间戳
                boolean success = atomicStampedRef.compareAndSet(refValue, refValue + 200, stamp, stamp + 1);
                System.out.println("refT2 Success:" + success);

            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        });

        refT1.start();
        refT2.start();

    }
}

