package com.ruoyi.ap;

import java.util.LinkedList;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.ReentrantLock;

public class ProducerConsumerModel {
    // 创建一个LinkedList队列来存储生产的元素
    private final LinkedList<Integer> queue = new LinkedList<>();
    // 设置队列的最大容量
    private final int CAPACITY = 10;
    // 创建一个可重入锁
    private final ReentrantLock lock = new ReentrantLock();
    // 创建两个条件，一个用于队列未满，一个用于队列非空
    private final Condition notFull = lock.newCondition();
    private final Condition notEmpty = lock.newCondition();

    // 生产者方法
    public void produce(int value) throws InterruptedException {
        // 获取锁
        lock.lock();
        try {
            // 如果队列满了，就让生产者线程等待
            while (queue.size() == CAPACITY) {
                notFull.await();
            }
            // 向队列中添加元素
            queue.add(value);
            System.out.println("Produced " + value);
            // 生产完毕，通知所有正在等待队列非空的消费者线程
            notEmpty.signalAll();
        } finally {
            // 最后，无论如何都要释放锁
            lock.unlock();
        }
    }

    // 消费者方法
    public void consume() throws InterruptedException {
        // 获取锁
        lock.lock();
        try {
            // 如果队列空了，就让消费者线程等待
            while (queue.isEmpty()) {
                notEmpty.await();
            }
            // 从队列中取出元素
            int value = queue.removeFirst();
            System.out.println("Consumed " + value);
            // 消费完毕，通知所有正在等待队列未满的生产者线程
            notFull.signalAll();
        } finally {
            // 最后，无论如何都要释放锁
            lock.unlock();
        }
    }
}


